#  -------------------------------------------------------------------------
#  pyCGNS - Python package for CFD General Notation System -
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
#

from CGNS.MAP import test
test.run()

from CGNS.PAT import test
test.run()

from CGNS.VAL import test
test.run()

from CGNS.NAV import test
test.run()

from CGNS.DAT import test
test.run()

from CGNS.APP import test
test.run()

# --- last line

