# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7SelectionWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7SelectionWindow(object):
    def setupUi(self, Q7SelectionWindow):
        Q7SelectionWindow.setObjectName("Q7SelectionWindow")
        Q7SelectionWindow.resize(715, 350)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7SelectionWindow.sizePolicy().hasHeightForWidth())
        Q7SelectionWindow.setSizePolicy(sizePolicy)
        Q7SelectionWindow.setMinimumSize(QtCore.QSize(0, 0))
        Q7SelectionWindow.setMaximumSize(QtCore.QSize(90000, 90000))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7SelectionWindow.setWindowIcon(icon)
        self.gridLayout = QtWidgets.QGridLayout(Q7SelectionWindow)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bBackControl = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon1)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_2.addWidget(self.bBackControl)
        self.bInfo = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon2)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_2.addWidget(self.bInfo)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.bClose = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bClose.setObjectName("bClose")
        self.horizontalLayout_2.addWidget(self.bClose)
        self.gridLayout.addLayout(self.horizontalLayout_2, 7, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.bPrevious = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bPrevious.setEnabled(False)
        self.bPrevious.setMinimumSize(QtCore.QSize(25, 25))
        self.bPrevious.setMaximumSize(QtCore.QSize(25, 25))
        self.bPrevious.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/control.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bPrevious.setIcon(icon3)
        self.bPrevious.setObjectName("bPrevious")
        self.horizontalLayout.addWidget(self.bPrevious)
        self.bFirst = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bFirst.setEnabled(False)
        self.bFirst.setMinimumSize(QtCore.QSize(25, 25))
        self.bFirst.setMaximumSize(QtCore.QSize(25, 25))
        self.bFirst.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/node-sids-leaf.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bFirst.setIcon(icon4)
        self.bFirst.setObjectName("bFirst")
        self.horizontalLayout.addWidget(self.bFirst)
        self.bNext = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bNext.setEnabled(False)
        self.bNext.setMinimumSize(QtCore.QSize(25, 25))
        self.bNext.setMaximumSize(QtCore.QSize(25, 25))
        self.bNext.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/node-sids-closed.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bNext.setIcon(icon5)
        self.bNext.setObjectName("bNext")
        self.horizontalLayout.addWidget(self.bNext)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.bSelectAll = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bSelectAll.setMinimumSize(QtCore.QSize(25, 25))
        self.bSelectAll.setMaximumSize(QtCore.QSize(25, 25))
        self.bSelectAll.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/select-add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSelectAll.setIcon(icon6)
        self.bSelectAll.setObjectName("bSelectAll")
        self.horizontalLayout.addWidget(self.bSelectAll)
        self.bReverse = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bReverse.setMinimumSize(QtCore.QSize(25, 25))
        self.bReverse.setMaximumSize(QtCore.QSize(25, 25))
        self.bReverse.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/images/icons/flag-revert.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bReverse.setIcon(icon7)
        self.bReverse.setObjectName("bReverse")
        self.horizontalLayout.addWidget(self.bReverse)
        self.bUnselectAll = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bUnselectAll.setMinimumSize(QtCore.QSize(25, 25))
        self.bUnselectAll.setMaximumSize(QtCore.QSize(25, 25))
        self.bUnselectAll.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/images/icons/select-delete.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bUnselectAll.setIcon(icon8)
        self.bUnselectAll.setObjectName("bUnselectAll")
        self.horizontalLayout.addWidget(self.bUnselectAll)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.bRemoveToSelect = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bRemoveToSelect.setText("")
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/images/icons/flag-none.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRemoveToSelect.setIcon(icon9)
        self.bRemoveToSelect.setObjectName("bRemoveToSelect")
        self.horizontalLayout.addWidget(self.bRemoveToSelect)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.bSave = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bSave.setMinimumSize(QtCore.QSize(25, 25))
        self.bSave.setMaximumSize(QtCore.QSize(25, 25))
        self.bSave.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/images/icons/select-save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSave.setIcon(icon10)
        self.bSave.setObjectName("bSave")
        self.horizontalLayout.addWidget(self.bSave)
        self.gridLayout.addLayout(self.horizontalLayout, 3, 0, 1, 1)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.selectionTable = QtWidgets.QTableWidget(Q7SelectionWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.selectionTable.sizePolicy().hasHeightForWidth())
        self.selectionTable.setSizePolicy(sizePolicy)
        self.selectionTable.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.selectionTable.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.selectionTable.setAutoScroll(False)
        self.selectionTable.setEditTriggers(QtWidgets.QAbstractItemView.DoubleClicked|QtWidgets.QAbstractItemView.EditKeyPressed)
        self.selectionTable.setDragDropOverwriteMode(False)
        self.selectionTable.setAlternatingRowColors(False)
        self.selectionTable.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.selectionTable.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.selectionTable.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.selectionTable.setColumnCount(1)
        self.selectionTable.setObjectName("selectionTable")
        self.selectionTable.setRowCount(0)
        self.verticalLayout.addWidget(self.selectionTable)
        self.gridLayout.addLayout(self.verticalLayout, 6, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label = QtWidgets.QLabel(Q7SelectionWindow)
        self.label.setObjectName("label")
        self.horizontalLayout_3.addWidget(self.label)
        self.cShowSIDS = QtWidgets.QCheckBox(Q7SelectionWindow)
        self.cShowSIDS.setChecked(False)
        self.cShowSIDS.setObjectName("cShowSIDS")
        self.horizontalLayout_3.addWidget(self.cShowSIDS)
        self.cShowPath = QtWidgets.QCheckBox(Q7SelectionWindow)
        self.cShowPath.setChecked(True)
        self.cShowPath.setObjectName("cShowPath")
        self.horizontalLayout_3.addWidget(self.cShowPath)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem4)
        self.cForce = QtWidgets.QCheckBox(Q7SelectionWindow)
        self.cForce.setEnabled(True)
        self.cForce.setCheckable(True)
        self.cForce.setChecked(True)
        self.cForce.setObjectName("cForce")
        self.horizontalLayout_3.addWidget(self.cForce)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem5)
        self.bApply = QtWidgets.QPushButton(Q7SelectionWindow)
        self.bApply.setMinimumSize(QtCore.QSize(25, 25))
        self.bApply.setText("")
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/images/icons/operate-execute.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bApply.setIcon(icon11)
        self.bApply.setObjectName("bApply")
        self.horizontalLayout_3.addWidget(self.bApply)
        self.cApplyToAll = QtWidgets.QCheckBox(Q7SelectionWindow)
        self.cApplyToAll.setEnabled(True)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/images/icons/user-G.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cApplyToAll.setIcon(icon12)
        self.cApplyToAll.setObjectName("cApplyToAll")
        self.horizontalLayout_3.addWidget(self.cApplyToAll)
        self.gridLayout.addLayout(self.horizontalLayout_3, 5, 0, 1, 1)
        self.line = QtWidgets.QFrame(Q7SelectionWindow)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout.addWidget(self.line, 4, 0, 1, 1)

        self.retranslateUi(Q7SelectionWindow)
        QtCore.QMetaObject.connectSlotsByName(Q7SelectionWindow)

    def retranslateUi(self, Q7SelectionWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7SelectionWindow.setWindowTitle(_translate("Q7SelectionWindow", "Form"))
        self.bClose.setText(_translate("Q7SelectionWindow", "Close"))
        self.bSelectAll.setToolTip(_translate("Q7SelectionWindow", "XOR"))
        self.selectionTable.setSortingEnabled(True)
        self.label.setText(_translate("Q7SelectionWindow", "Show:"))
        self.cShowSIDS.setText(_translate("Q7SelectionWindow", "SIDS"))
        self.cShowPath.setText(_translate("Q7SelectionWindow", "Path"))
        self.cForce.setText(_translate("Q7SelectionWindow", "Force value check"))
        self.bApply.setToolTip(_translate("Q7SelectionWindow", "Apply changes"))
        self.cApplyToAll.setText(_translate("Q7SelectionWindow", "Apply to All Selected"))
from . import Res_rc
