# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7FormWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7FormWindow(object):
    def setupUi(self, Q7FormWindow):
        Q7FormWindow.setObjectName("Q7FormWindow")
        Q7FormWindow.resize(550, 600)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7FormWindow.sizePolicy().hasHeightForWidth())
        Q7FormWindow.setSizePolicy(sizePolicy)
        Q7FormWindow.setMinimumSize(QtCore.QSize(550, 600))
        Q7FormWindow.setMaximumSize(QtCore.QSize(999999, 999999))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7FormWindow.setWindowIcon(icon)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(Q7FormWindow)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bLockPanel = QtWidgets.QPushButton(Q7FormWindow)
        self.bLockPanel.setEnabled(False)
        self.bLockPanel.setMinimumSize(QtCore.QSize(25, 25))
        self.bLockPanel.setMaximumSize(QtCore.QSize(25, 25))
        self.bLockPanel.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/panel-lock.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bLockPanel.setIcon(icon1)
        self.bLockPanel.setObjectName("bLockPanel")
        self.horizontalLayout_2.addWidget(self.bLockPanel)
        self.ePath = QtWidgets.QLineEdit(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ePath.sizePolicy().hasHeightForWidth())
        self.ePath.setSizePolicy(sizePolicy)
        self.ePath.setMinimumSize(QtCore.QSize(510, 0))
        self.ePath.setObjectName("ePath")
        self.horizontalLayout_2.addWidget(self.ePath)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_2 = QtWidgets.QLabel(Q7FormWindow)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.eName = QtWidgets.QLineEdit(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eName.sizePolicy().hasHeightForWidth())
        self.eName.setSizePolicy(sizePolicy)
        self.eName.setMinimumSize(QtCore.QSize(220, 0))
        self.eName.setObjectName("eName")
        self.horizontalLayout.addWidget(self.eName)
        self.label_3 = QtWidgets.QLabel(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout.addWidget(self.label_3)
        self.eType = QtWidgets.QComboBox(Q7FormWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eType.sizePolicy().hasHeightForWidth())
        self.eType.setSizePolicy(sizePolicy)
        self.eType.setMinimumSize(QtCore.QSize(200, 0))
        self.eType.setObjectName("eType")
        self.horizontalLayout.addWidget(self.eType)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(Q7FormWindow)
        self.tabWidget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        self.tData = QtWidgets.QWidget()
        self.tData.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tData.sizePolicy().hasHeightForWidth())
        self.tData.setSizePolicy(sizePolicy)
        self.tData.setObjectName("tData")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.tData)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame_3 = QtWidgets.QFrame(self.tData)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_3.sizePolicy().hasHeightForWidth())
        self.frame_3.setSizePolicy(sizePolicy)
        self.frame_3.setMinimumSize(QtCore.QSize(600, 60))
        self.frame_3.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_3.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.label_6 = QtWidgets.QLabel(self.frame_3)
        self.label_6.setGeometry(QtCore.QRect(6, 40, 602, 16))
        self.label_6.setObjectName("label_6")
        self.eItems = QtWidgets.QLineEdit(self.frame_3)
        self.eItems.setGeometry(QtCore.QRect(46, 35, 160, 22))
        self.eItems.setObjectName("eItems")
        self.label = QtWidgets.QLabel(self.frame_3)
        self.label.setGeometry(QtCore.QRect(5, 10, 32, 16))
        self.label.setObjectName("label")
        self.cDataType = QtWidgets.QComboBox(self.frame_3)
        self.cDataType.setGeometry(QtCore.QRect(45, 5, 51, 23))
        self.cDataType.setObjectName("cDataType")
        self.eDims = QtWidgets.QLineEdit(self.frame_3)
        self.eDims.setGeometry(QtCore.QRect(96, 5, 111, 24))
        self.eDims.setObjectName("eDims")
        self.line = QtWidgets.QFrame(self.frame_3)
        self.line.setGeometry(QtCore.QRect(213, 4, 16, 46))
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_5 = QtWidgets.QLabel(self.frame_3)
        self.label_5.setGeometry(QtCore.QRect(230, 10, 58, 16))
        self.label_5.setObjectName("label_5")
        self.label_24 = QtWidgets.QLabel(self.frame_3)
        self.label_24.setGeometry(QtCore.QRect(230, 35, 47, 16))
        self.label_24.setObjectName("label_24")
        self.sMinH = QtWidgets.QSpinBox(self.frame_3)
        self.sMinH.setGeometry(QtCore.QRect(270, 6, 92, 22))
        self.sMinH.setObjectName("sMinH")
        self.label_7 = QtWidgets.QLabel(self.frame_3)
        self.label_7.setGeometry(QtCore.QRect(370, 10, 58, 16))
        self.label_7.setObjectName("label_7")
        self.sMinV = QtWidgets.QSpinBox(self.frame_3)
        self.sMinV.setGeometry(QtCore.QRect(415, 5, 81, 22))
        self.sMinV.setObjectName("sMinV")
        self.cRowColSize = QtWidgets.QComboBox(self.frame_3)
        self.cRowColSize.setGeometry(QtCore.QRect(270, 35, 196, 22))
        self.cRowColSize.setObjectName("cRowColSize")
        self.bMinimize = QtWidgets.QPushButton(self.frame_3)
        self.bMinimize.setGeometry(QtCore.QRect(470, 34, 25, 25))
        self.bMinimize.setMinimumSize(QtCore.QSize(25, 25))
        self.bMinimize.setMaximumSize(QtCore.QSize(25, 25))
        self.bMinimize.setObjectName("bMinimize")
        self.verticalLayout.addWidget(self.frame_3)
        self.frame_5 = QtWidgets.QFrame(self.tData)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_5.sizePolicy().hasHeightForWidth())
        self.frame_5.setSizePolicy(sizePolicy)
        self.frame_5.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_5.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_5.setObjectName("frame_5")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.frame_5)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.tableView = Q7TableView(self.frame_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableView.sizePolicy().hasHeightForWidth())
        self.tableView.setSizePolicy(sizePolicy)
        self.tableView.setMinimumSize(QtCore.QSize(100, 100))
        self.tableView.viewport().setProperty("cursor", QtGui.QCursor(QtCore.Qt.CrossCursor))
        self.tableView.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.tableView.setAutoFillBackground(False)
        self.tableView.setSelectionMode(QtWidgets.QAbstractItemView.ContiguousSelection)
        self.tableView.setObjectName("tableView")
        self.tableView.horizontalHeader().setCascadingSectionResizes(False)
        self.tableView.verticalHeader().setCascadingSectionResizes(False)
        self.verticalLayout_12.addWidget(self.tableView)
        self.verticalLayout.addWidget(self.frame_5)
        self.verticalLayout_8.addLayout(self.verticalLayout)
        self.tabWidget.addTab(self.tData, "")
        self.tFiles = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tFiles.sizePolicy().hasHeightForWidth())
        self.tFiles.setSizePolicy(sizePolicy)
        self.tFiles.setObjectName("tFiles")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.tFiles)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tFiles)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setObjectName("groupBox_3")
        self.label_9 = QtWidgets.QLabel(self.groupBox_3)
        self.label_9.setGeometry(QtCore.QRect(5, 25, 59, 27))
        self.label_9.setObjectName("label_9")
        self.eDestPath = QtWidgets.QLineEdit(self.groupBox_3)
        self.eDestPath.setGeometry(QtCore.QRect(40, 24, 453, 27))
        self.eDestPath.setObjectName("eDestPath")
        self.label_10 = QtWidgets.QLabel(self.groupBox_3)
        self.label_10.setGeometry(QtCore.QRect(6, 60, 45, 17))
        self.label_10.setObjectName("label_10")
        self.eDestFile = QtWidgets.QLineEdit(self.groupBox_3)
        self.eDestFile.setGeometry(QtCore.QRect(40, 54, 299, 27))
        self.eDestFile.setObjectName("eDestFile")
        self.label_23 = QtWidgets.QLabel(self.groupBox_3)
        self.label_23.setGeometry(QtCore.QRect(6, 121, 31, 17))
        self.label_23.setObjectName("label_23")
        self.lineEdit_18 = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEdit_18.setGeometry(QtCore.QRect(40, 115, 178, 27))
        self.lineEdit_18.setObjectName("lineEdit_18")
        self.label_8 = QtWidgets.QLabel(self.groupBox_3)
        self.label_8.setGeometry(QtCore.QRect(385, 60, 58, 16))
        self.label_8.setObjectName("label_8")
        self.lineEdit_2 = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEdit_2.setGeometry(QtCore.QRect(453, 55, 39, 22))
        self.lineEdit_2.setObjectName("lineEdit_2")
        self.eDestDir = QtWidgets.QLineEdit(self.groupBox_3)
        self.eDestDir.setGeometry(QtCore.QRect(40, 84, 298, 27))
        self.eDestDir.setObjectName("eDestDir")
        self.label_13 = QtWidgets.QLabel(self.groupBox_3)
        self.label_13.setGeometry(QtCore.QRect(5, 89, 45, 17))
        self.label_13.setObjectName("label_13")
        self.groupBox = QtWidgets.QGroupBox(self.groupBox_3)
        self.groupBox.setGeometry(QtCore.QRect(8, 160, 492, 96))
        self.groupBox.setObjectName("groupBox")
        self.checkBox_11 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_11.setGeometry(QtCore.QRect(10, 21, 151, 22))
        self.checkBox_11.setObjectName("checkBox_11")
        self.checkBox_8 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_8.setGeometry(QtCore.QRect(10, 43, 188, 22))
        self.checkBox_8.setObjectName("checkBox_8")
        self.checkBox_10 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_10.setGeometry(QtCore.QRect(10, 66, 188, 22))
        self.checkBox_10.setObjectName("checkBox_10")
        self.checkBox_18 = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_18.setGeometry(QtCore.QRect(205, 20, 203, 22))
        self.checkBox_18.setObjectName("checkBox_18")
        self.cChildOfLink = QtWidgets.QCheckBox(self.groupBox)
        self.cChildOfLink.setGeometry(QtCore.QRect(205, 45, 232, 21))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.cChildOfLink.setFont(font)
        self.cChildOfLink.setObjectName("cChildOfLink")
        self.verticalLayout_6.addWidget(self.groupBox_3)
        self.verticalLayout_9.addLayout(self.verticalLayout_6)
        self.tabWidget.addTab(self.tFiles, "")
        self.tText = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tText.sizePolicy().hasHeightForWidth())
        self.tText.setSizePolicy(sizePolicy)
        self.tText.setObjectName("tText")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.tText)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.cFortranOrderOff = QtWidgets.QCheckBox(self.tText)
        self.cFortranOrderOff.setObjectName("cFortranOrderOff")
        self.horizontalLayout_4.addWidget(self.cFortranOrderOff)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.bRevert = QtWidgets.QPushButton(self.tText)
        self.bRevert.setMinimumSize(QtCore.QSize(25, 25))
        self.bRevert.setMaximumSize(QtCore.QSize(25, 25))
        self.bRevert.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/subtree-sids-failed.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRevert.setIcon(icon2)
        self.bRevert.setObjectName("bRevert")
        self.horizontalLayout_4.addWidget(self.bRevert)
        self.bCommit = QtWidgets.QPushButton(self.tText)
        self.bCommit.setMinimumSize(QtCore.QSize(25, 25))
        self.bCommit.setMaximumSize(QtCore.QSize(25, 25))
        self.bCommit.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/save-log.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bCommit.setIcon(icon3)
        self.bCommit.setObjectName("bCommit")
        self.horizontalLayout_4.addWidget(self.bCommit)
        self.verticalLayout_10.addLayout(self.horizontalLayout_4)
        self.eText = Q7PythonEditor(self.tText)
        self.eText.setObjectName("eText")
        self.verticalLayout_10.addWidget(self.eText)
        self.tabWidget.addTab(self.tText, "")
        self.tPython = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tPython.sizePolicy().hasHeightForWidth())
        self.tPython.setSizePolicy(sizePolicy)
        self.tPython.setObjectName("tPython")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.tPython)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.frame_6 = QtWidgets.QFrame(self.tPython)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_6.sizePolicy().hasHeightForWidth())
        self.frame_6.setSizePolicy(sizePolicy)
        self.frame_6.setMinimumSize(QtCore.QSize(550, 125))
        self.frame_6.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setObjectName("frame_6")
        self.label_11 = QtWidgets.QLabel(self.frame_6)
        self.label_11.setGeometry(QtCore.QRect(5, 5, 33, 27))
        self.label_11.setObjectName("label_11")
        self.comboBox_5 = QtWidgets.QComboBox(self.frame_6)
        self.comboBox_5.setGeometry(QtCore.QRect(55, 5, 101, 27))
        self.comboBox_5.setObjectName("comboBox_5")
        self.label_26 = QtWidgets.QLabel(self.frame_6)
        self.label_26.setGeometry(QtCore.QRect(5, 37, 41, 27))
        self.label_26.setObjectName("label_26")
        self.lineEdit_20 = QtWidgets.QLineEdit(self.frame_6)
        self.lineEdit_20.setGeometry(QtCore.QRect(55, 36, 171, 27))
        self.lineEdit_20.setObjectName("lineEdit_20")
        self.label_27 = QtWidgets.QLabel(self.frame_6)
        self.label_27.setGeometry(QtCore.QRect(3, 65, 51, 27))
        self.label_27.setObjectName("label_27")
        self.lineEdit_21 = QtWidgets.QLineEdit(self.frame_6)
        self.lineEdit_21.setGeometry(QtCore.QRect(55, 65, 171, 27))
        self.lineEdit_21.setObjectName("lineEdit_21")
        self.label_28 = QtWidgets.QLabel(self.frame_6)
        self.label_28.setGeometry(QtCore.QRect(6, 91, 51, 27))
        self.label_28.setObjectName("label_28")
        self.lineEdit_22 = QtWidgets.QLineEdit(self.frame_6)
        self.lineEdit_22.setGeometry(QtCore.QRect(55, 96, 171, 26))
        self.lineEdit_22.setObjectName("lineEdit_22")
        self.checkBox_5 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_5.setGeometry(QtCore.QRect(255, 5, 161, 22))
        self.checkBox_5.setObjectName("checkBox_5")
        self.checkBox_6 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_6.setGeometry(QtCore.QRect(255, 24, 161, 22))
        self.checkBox_6.setObjectName("checkBox_6")
        self.checkBox_9 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_9.setGeometry(QtCore.QRect(254, 43, 161, 22))
        self.checkBox_9.setObjectName("checkBox_9")
        self.checkBox_21 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_21.setGeometry(QtCore.QRect(385, 7, 161, 22))
        self.checkBox_21.setObjectName("checkBox_21")
        self.checkBox_7 = QtWidgets.QCheckBox(self.frame_6)
        self.checkBox_7.setGeometry(QtCore.QRect(384, 26, 161, 22))
        self.checkBox_7.setObjectName("checkBox_7")
        self.pushButton = QtWidgets.QPushButton(self.frame_6)
        self.pushButton.setGeometry(QtCore.QRect(332, 95, 161, 27))
        self.pushButton.setObjectName("pushButton")
        self.verticalLayout_7.addWidget(self.frame_6)
        self.plainTextEdit = Q7PythonEditor(self.tPython)
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.verticalLayout_7.addWidget(self.plainTextEdit)
        self.verticalLayout_11.addLayout(self.verticalLayout_7)
        self.tabWidget.addTab(self.tPython, "")
        self.verticalLayout_2.addWidget(self.tabWidget)
        self.verticalLayout_3.addLayout(self.verticalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.bBackControl = QtWidgets.QPushButton(Q7FormWindow)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon4)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_3.addWidget(self.bBackControl)
        self.bInfo = QtWidgets.QPushButton(Q7FormWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon5)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_3.addWidget(self.bInfo)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.bClose = QtWidgets.QPushButton(Q7FormWindow)
        self.bClose.setObjectName("bClose")
        self.horizontalLayout_3.addWidget(self.bClose)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)

        self.retranslateUi(Q7FormWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Q7FormWindow)

    def retranslateUi(self, Q7FormWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7FormWindow.setWindowTitle(_translate("Q7FormWindow", "Form"))
        self.label_2.setText(_translate("Q7FormWindow", "Name"))
        self.label_3.setText(_translate("Q7FormWindow", "Label"))
        self.label_6.setText(_translate("Q7FormWindow", "Items"))
        self.label.setText(_translate("Q7FormWindow", "Data"))
        self.label_5.setText(_translate("Q7FormWindow", "min H"))
        self.label_24.setText(_translate("Q7FormWindow", "Size"))
        self.label_7.setText(_translate("Q7FormWindow", "min V"))
        self.bMinimize.setText(_translate("Q7FormWindow", "fit"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tData), _translate("Q7FormWindow", "Table"))
        self.groupBox_3.setTitle(_translate("Q7FormWindow", "Node"))
        self.label_9.setText(_translate("Q7FormWindow", "Path"))
        self.label_10.setText(_translate("Q7FormWindow", "File"))
        self.label_23.setText(_translate("Q7FormWindow", "Size"))
        self.label_8.setText(_translate("Q7FormWindow", "Link level"))
        self.label_13.setText(_translate("Q7FormWindow", "Dir"))
        self.groupBox.setTitle(_translate("Q7FormWindow", "Status"))
        self.checkBox_11.setText(_translate("Q7FormWindow", "Link not found"))
        self.checkBox_8.setText(_translate("Q7FormWindow", "Destination File Read Only"))
        self.checkBox_10.setText(_translate("Q7FormWindow", "Node not found in file"))
        self.checkBox_18.setText(_translate("Q7FormWindow", "File load without following links"))
        self.cChildOfLink.setText(_translate("Q7FormWindow", "Child of a linked node"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tFiles), _translate("Q7FormWindow", "Link"))
        self.cFortranOrderOff.setText(_translate("Q7FormWindow", "Fortran order array is transposed"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tText), _translate("Q7FormWindow", "Text"))
        self.label_11.setText(_translate("Q7FormWindow", "Type"))
        self.label_26.setText(_translate("Q7FormWindow", "Shape"))
        self.label_27.setText(_translate("Q7FormWindow", "Strides"))
        self.label_28.setText(_translate("Q7FormWindow", "Base"))
        self.checkBox_5.setText(_translate("Q7FormWindow", "Data owner"))
        self.checkBox_6.setText(_translate("Q7FormWindow", "Fortran order"))
        self.checkBox_9.setText(_translate("Q7FormWindow", "Contiguous"))
        self.checkBox_21.setText(_translate("Q7FormWindow", "View"))
        self.checkBox_7.setText(_translate("Q7FormWindow", "C order"))
        self.pushButton.setText(_translate("Q7FormWindow", "Run on NODE variable"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tPython), _translate("Q7FormWindow", "Python"))
        self.bClose.setText(_translate("Q7FormWindow", "Close"))
from CGNS.NAV.mtable import Q7TableView
from CGNS.NAV.weditors import Q7PythonEditor
from . import Res_rc
