# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7VTKWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7VTKWindow(object):
    def setupUi(self, Q7VTKWindow):
        Q7VTKWindow.setObjectName("Q7VTKWindow")
        Q7VTKWindow.resize(700, 402)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7VTKWindow.sizePolicy().hasHeightForWidth())
        Q7VTKWindow.setSizePolicy(sizePolicy)
        Q7VTKWindow.setMinimumSize(QtCore.QSize(700, 400))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7VTKWindow.setWindowIcon(icon)
        self.verticalLayout = QtWidgets.QVBoxLayout(Q7VTKWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.cViews = QtWidgets.QComboBox(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cViews.sizePolicy().hasHeightForWidth())
        self.cViews.setSizePolicy(sizePolicy)
        self.cViews.setEditable(True)
        self.cViews.setMaxCount(16)
        self.cViews.setInsertPolicy(QtWidgets.QComboBox.InsertAtTop)
        self.cViews.setObjectName("cViews")
        self.horizontalLayout.addWidget(self.cViews)
        self.bAddView = QtWidgets.QPushButton(Q7VTKWindow)
        self.bAddView.setMinimumSize(QtCore.QSize(25, 25))
        self.bAddView.setMaximumSize(QtCore.QSize(25, 25))
        self.bAddView.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/camera-add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bAddView.setIcon(icon1)
        self.bAddView.setObjectName("bAddView")
        self.horizontalLayout.addWidget(self.bAddView)
        self.bSaveView = QtWidgets.QPushButton(Q7VTKWindow)
        self.bSaveView.setMinimumSize(QtCore.QSize(25, 25))
        self.bSaveView.setMaximumSize(QtCore.QSize(25, 25))
        self.bSaveView.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/camera-snap.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveView.setIcon(icon2)
        self.bSaveView.setObjectName("bSaveView")
        self.horizontalLayout.addWidget(self.bSaveView)
        self.bRemoveView = QtWidgets.QPushButton(Q7VTKWindow)
        self.bRemoveView.setMinimumSize(QtCore.QSize(25, 25))
        self.bRemoveView.setMaximumSize(QtCore.QSize(25, 25))
        self.bRemoveView.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/camera-remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRemoveView.setIcon(icon3)
        self.bRemoveView.setObjectName("bRemoveView")
        self.horizontalLayout.addWidget(self.bRemoveView)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.bColorMapMin = QtWidgets.QPushButton(Q7VTKWindow)
        self.bColorMapMin.setMinimumSize(QtCore.QSize(25, 25))
        self.bColorMapMin.setMaximumSize(QtCore.QSize(25, 25))
        self.bColorMapMin.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/colors-first.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bColorMapMin.setIcon(icon4)
        self.bColorMapMin.setObjectName("bColorMapMin")
        self.horizontalLayout.addWidget(self.bColorMapMin)
        self.bColorMapMax = QtWidgets.QPushButton(Q7VTKWindow)
        self.bColorMapMax.setMinimumSize(QtCore.QSize(25, 25))
        self.bColorMapMax.setMaximumSize(QtCore.QSize(25, 25))
        self.bColorMapMax.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/colors-last.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bColorMapMax.setIcon(icon5)
        self.bColorMapMax.setObjectName("bColorMapMax")
        self.horizontalLayout.addWidget(self.bColorMapMax)
        self.cVariables = QtWidgets.QComboBox(Q7VTKWindow)
        self.cVariables.setObjectName("cVariables")
        self.horizontalLayout.addWidget(self.cVariables)
        self.cColorSpace = QtWidgets.QComboBox(Q7VTKWindow)
        self.cColorSpace.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.cColorSpace.setObjectName("cColorSpace")
        self.horizontalLayout.addWidget(self.cColorSpace)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.bSaveVTK = QtWidgets.QPushButton(Q7VTKWindow)
        self.bSaveVTK.setMinimumSize(QtCore.QSize(25, 25))
        self.bSaveVTK.setMaximumSize(QtCore.QSize(25, 25))
        self.bSaveVTK.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveVTK.setIcon(icon6)
        self.bSaveVTK.setObjectName("bSaveVTK")
        self.horizontalLayout.addWidget(self.bSaveVTK)
        self.bScreenShot = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bScreenShot.sizePolicy().hasHeightForWidth())
        self.bScreenShot.setSizePolicy(sizePolicy)
        self.bScreenShot.setMinimumSize(QtCore.QSize(25, 25))
        self.bScreenShot.setMaximumSize(QtCore.QSize(25, 25))
        self.bScreenShot.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/images/icons/snapshot.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bScreenShot.setIcon(icon7)
        self.bScreenShot.setObjectName("bScreenShot")
        self.horizontalLayout.addWidget(self.bScreenShot)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.line = QtWidgets.QFrame(Q7VTKWindow)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout.addWidget(self.line)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.bX = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bX.sizePolicy().hasHeightForWidth())
        self.bX.setSizePolicy(sizePolicy)
        self.bX.setMinimumSize(QtCore.QSize(25, 25))
        self.bX.setMaximumSize(QtCore.QSize(25, 25))
        self.bX.setObjectName("bX")
        self.horizontalLayout_3.addWidget(self.bX)
        self.bY = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bY.sizePolicy().hasHeightForWidth())
        self.bY.setSizePolicy(sizePolicy)
        self.bY.setMinimumSize(QtCore.QSize(25, 25))
        self.bY.setMaximumSize(QtCore.QSize(25, 25))
        self.bY.setObjectName("bY")
        self.horizontalLayout_3.addWidget(self.bY)
        self.bZ = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bZ.sizePolicy().hasHeightForWidth())
        self.bZ.setSizePolicy(sizePolicy)
        self.bZ.setMinimumSize(QtCore.QSize(25, 25))
        self.bZ.setMaximumSize(QtCore.QSize(25, 25))
        self.bZ.setObjectName("bZ")
        self.horizontalLayout_3.addWidget(self.bZ)
        self.cMirror = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cMirror.setObjectName("cMirror")
        self.horizontalLayout_3.addWidget(self.cMirror)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.bZoom = QtWidgets.QPushButton(Q7VTKWindow)
        self.bZoom.setMinimumSize(QtCore.QSize(25, 25))
        self.bZoom.setMaximumSize(QtCore.QSize(25, 25))
        self.bZoom.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/images/icons/zoompoint.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bZoom.setIcon(icon8)
        self.bZoom.setCheckable(True)
        self.bZoom.setObjectName("bZoom")
        self.horizontalLayout_3.addWidget(self.bZoom)
        self.selectable = QtWidgets.QPushButton(Q7VTKWindow)
        self.selectable.setMinimumSize(QtCore.QSize(25, 25))
        self.selectable.setMaximumSize(QtCore.QSize(25, 25))
        self.selectable.setCursor(QtGui.QCursor(QtCore.Qt.OpenHandCursor))
        self.selectable.setText("")
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/images/icons/lock-legend.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.selectable.setIcon(icon9)
        self.selectable.setCheckable(True)
        self.selectable.setObjectName("selectable")
        self.horizontalLayout_3.addWidget(self.selectable)
        self.cShowValue = QtWidgets.QPushButton(Q7VTKWindow)
        self.cShowValue.setMinimumSize(QtCore.QSize(25, 25))
        self.cShowValue.setMaximumSize(QtCore.QSize(25, 25))
        self.cShowValue.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/images/icons/value.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cShowValue.setIcon(icon10)
        self.cShowValue.setCheckable(True)
        self.cShowValue.setObjectName("cShowValue")
        self.horizontalLayout_3.addWidget(self.cShowValue)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.bSuffleColors = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bSuffleColors.sizePolicy().hasHeightForWidth())
        self.bSuffleColors.setSizePolicy(sizePolicy)
        self.bSuffleColors.setMinimumSize(QtCore.QSize(25, 25))
        self.bSuffleColors.setMaximumSize(QtCore.QSize(25, 25))
        self.bSuffleColors.setText("")
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/images/icons/colors.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSuffleColors.setIcon(icon11)
        self.bSuffleColors.setObjectName("bSuffleColors")
        self.horizontalLayout_3.addWidget(self.bSuffleColors)
        self.bBlackColor = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bBlackColor.sizePolicy().hasHeightForWidth())
        self.bBlackColor.setSizePolicy(sizePolicy)
        self.bBlackColor.setMinimumSize(QtCore.QSize(25, 25))
        self.bBlackColor.setMaximumSize(QtCore.QSize(25, 25))
        self.bBlackColor.setText("")
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/images/icons/colors-bw.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBlackColor.setIcon(icon12)
        self.bBlackColor.setObjectName("bBlackColor")
        self.horizontalLayout_3.addWidget(self.bBlackColor)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem4)
        self.bAnimateWindow = QtWidgets.QPushButton(Q7VTKWindow)
        self.bAnimateWindow.setMinimumSize(QtCore.QSize(25, 25))
        self.bAnimateWindow.setMaximumSize(QtCore.QSize(25, 25))
        self.bAnimateWindow.setText("")
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/images/icons/anim-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bAnimateWindow.setIcon(icon13)
        self.bAnimateWindow.setObjectName("bAnimateWindow")
        self.horizontalLayout_3.addWidget(self.bAnimateWindow)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem5)
        self.bResetCamera = QtWidgets.QPushButton(Q7VTKWindow)
        self.bResetCamera.setMinimumSize(QtCore.QSize(25, 25))
        self.bResetCamera.setMaximumSize(QtCore.QSize(25, 25))
        self.bResetCamera.setText("")
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/images/icons/zoom-actor.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bResetCamera.setIcon(icon14)
        self.bResetCamera.setObjectName("bResetCamera")
        self.horizontalLayout_3.addWidget(self.bResetCamera)
        self.cRotationAxis = QtWidgets.QComboBox(Q7VTKWindow)
        self.cRotationAxis.setObjectName("cRotationAxis")
        self.horizontalLayout_3.addWidget(self.cRotationAxis)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.display = Q7VTKRenderWindowInteractor(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.display.sizePolicy().hasHeightForWidth())
        self.display.setSizePolicy(sizePolicy)
        self.display.setObjectName("display")
        self.verticalLayout_2.addWidget(self.display)
        self.verticalLayout.addLayout(self.verticalLayout_2)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.bUpdateFromTree = QtWidgets.QPushButton(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(25)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.bUpdateFromTree.sizePolicy().hasHeightForWidth())
        self.bUpdateFromTree.setSizePolicy(sizePolicy)
        self.bUpdateFromTree.setMinimumSize(QtCore.QSize(25, 25))
        self.bUpdateFromTree.setMaximumSize(QtCore.QSize(25, 25))
        self.bUpdateFromTree.setText("")
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/images/icons/user-U.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bUpdateFromTree.setIcon(icon15)
        self.bUpdateFromTree.setObjectName("bUpdateFromTree")
        self.horizontalLayout_4.addWidget(self.bUpdateFromTree)
        self.cCurrentPath = Q7ComboBox(Q7VTKWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cCurrentPath.sizePolicy().hasHeightForWidth())
        self.cCurrentPath.setSizePolicy(sizePolicy)
        self.cCurrentPath.setEditable(False)
        self.cCurrentPath.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToMinimumContentsLength)
        self.cCurrentPath.setMinimumContentsLength(100)
        self.cCurrentPath.setObjectName("cCurrentPath")
        self.horizontalLayout_4.addWidget(self.cCurrentPath)
        self.bUpdateFromVTK = QtWidgets.QPushButton(Q7VTKWindow)
        self.bUpdateFromVTK.setMinimumSize(QtCore.QSize(25, 25))
        self.bUpdateFromVTK.setMaximumSize(QtCore.QSize(25, 25))
        self.bUpdateFromVTK.setText("")
        self.bUpdateFromVTK.setIcon(icon15)
        self.bUpdateFromVTK.setObjectName("bUpdateFromVTK")
        self.horizontalLayout_4.addWidget(self.bUpdateFromVTK)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.line_2 = QtWidgets.QFrame(Q7VTKWindow)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout.addWidget(self.line_2)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bBackControl = QtWidgets.QPushButton(Q7VTKWindow)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon16)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_2.addWidget(self.bBackControl)
        self.bInfo = QtWidgets.QPushButton(Q7VTKWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon17)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_2.addWidget(self.bInfo)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem6)
        self.sIndex1 = QtWidgets.QSpinBox(Q7VTKWindow)
        self.sIndex1.setObjectName("sIndex1")
        self.horizontalLayout_2.addWidget(self.sIndex1)
        self.sIndex2 = QtWidgets.QSpinBox(Q7VTKWindow)
        self.sIndex2.setObjectName("sIndex2")
        self.horizontalLayout_2.addWidget(self.sIndex2)
        self.sIndex3 = QtWidgets.QSpinBox(Q7VTKWindow)
        self.sIndex3.setObjectName("sIndex3")
        self.horizontalLayout_2.addWidget(self.sIndex3)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem7)
        self.cShowFamily = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowFamily.setChecked(True)
        self.cShowFamily.setObjectName("cShowFamily")
        self.horizontalLayout_2.addWidget(self.cShowFamily)
        self.cShowZone = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowZone.setChecked(True)
        self.cShowZone.setObjectName("cShowZone")
        self.horizontalLayout_2.addWidget(self.cShowZone)
        self.cShowBC = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowBC.setChecked(False)
        self.cShowBC.setObjectName("cShowBC")
        self.horizontalLayout_2.addWidget(self.cShowBC)
        self.cShowCT = QtWidgets.QCheckBox(Q7VTKWindow)
        self.cShowCT.setChecked(False)
        self.cShowCT.setObjectName("cShowCT")
        self.horizontalLayout_2.addWidget(self.cShowCT)
        self.bPrevious = QtWidgets.QPushButton(Q7VTKWindow)
        self.bPrevious.setMinimumSize(QtCore.QSize(25, 25))
        self.bPrevious.setMaximumSize(QtCore.QSize(25, 25))
        self.bPrevious.setText("")
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/images/icons/control.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bPrevious.setIcon(icon18)
        self.bPrevious.setObjectName("bPrevious")
        self.horizontalLayout_2.addWidget(self.bPrevious)
        self.bReset = QtWidgets.QPushButton(Q7VTKWindow)
        self.bReset.setMinimumSize(QtCore.QSize(25, 25))
        self.bReset.setMaximumSize(QtCore.QSize(25, 25))
        self.bReset.setText("")
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/images/icons/node-sids-leaf.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bReset.setIcon(icon19)
        self.bReset.setObjectName("bReset")
        self.horizontalLayout_2.addWidget(self.bReset)
        self.bNext = QtWidgets.QPushButton(Q7VTKWindow)
        self.bNext.setMinimumSize(QtCore.QSize(25, 25))
        self.bNext.setMaximumSize(QtCore.QSize(25, 25))
        self.bNext.setText("")
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/images/icons/node-sids-closed.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bNext.setIcon(icon20)
        self.bNext.setObjectName("bNext")
        self.horizontalLayout_2.addWidget(self.bNext)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(Q7VTKWindow)
        QtCore.QMetaObject.connectSlotsByName(Q7VTKWindow)

    def retranslateUi(self, Q7VTKWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7VTKWindow.setWindowTitle(_translate("Q7VTKWindow", "Form"))
        Q7VTKWindow.setToolTip(_translate("Q7VTKWindow", "Show value"))
        self.bAddView.setToolTip(_translate("Q7VTKWindow", "Add current view to view list"))
        self.bSaveView.setToolTip(_translate("Q7VTKWindow", "Write view list into a file"))
        self.bRemoveView.setToolTip(_translate("Q7VTKWindow", "Remove current view from view list"))
        self.bColorMapMin.setToolTip(_translate("Q7VTKWindow", "Set color for palette high bound"))
        self.bColorMapMax.setToolTip(_translate("Q7VTKWindow", "Set color for palette low bound"))
        self.bSaveVTK.setToolTip(_translate("Q7VTKWindow", "Save VTK data into a file"))
        self.bScreenShot.setToolTip(_translate("Q7VTKWindow", "Save view snapshot into a file"))
        self.bX.setToolTip(_translate("Q7VTKWindow", "Show Y/Z plane"))
        self.bX.setText(_translate("Q7VTKWindow", "X"))
        self.bY.setToolTip(_translate("Q7VTKWindow", "Show X/Z plane"))
        self.bY.setText(_translate("Q7VTKWindow", "Y"))
        self.bZ.setToolTip(_translate("Q7VTKWindow", "Show X/Y plane"))
        self.bZ.setText(_translate("Q7VTKWindow", "Z"))
        self.cMirror.setText(_translate("Q7VTKWindow", "Mirror"))
        self.bZoom.setToolTip(_translate("Q7VTKWindow", "Activate Mouse Zoom mode"))
        self.selectable.setToolTip(_translate("Q7VTKWindow", "Acticate Move Legend Mode"))
        self.cShowValue.setToolTip(_translate("Q7VTKWindow", "Activate Show Value Mode"))
        self.bSuffleColors.setToolTip(_translate("Q7VTKWindow", "Change colors to random"))
        self.bBlackColor.setToolTip(_translate("Q7VTKWindow", "Switch black/white colors"))
        self.bResetCamera.setToolTip(_translate("Q7VTKWindow", "Zoom and center on selected"))
        self.cRotationAxis.setToolTip(_translate("Q7VTKWindow", "Rotation axis"))
        self.bUpdateFromTree.setToolTip(_translate("Q7VTKWindow", "Reset VTK view selection from tree view FIRST selected node"))
        self.bUpdateFromVTK.setToolTip(_translate("Q7VTKWindow", "Reset tree view selection from ALL VTK view selected objects"))
        self.bBackControl.setToolTip(_translate("Q7VTKWindow", "Raise CGNS.NAV control window"))
        self.sIndex3.setToolTip(_translate("Q7VTKWindow", "Get/Set index for third dim"))
        self.cShowFamily.setText(_translate("Q7VTKWindow", "Families"))
        self.cShowZone.setText(_translate("Q7VTKWindow", "Zones"))
        self.cShowBC.setText(_translate("Q7VTKWindow", "BCs"))
        self.cShowCT.setText(_translate("Q7VTKWindow", "CTs"))
        self.bPrevious.setToolTip(_translate("Q7VTKWindow", "Highlight previous selected item"))
        self.bReset.setToolTip(_translate("Q7VTKWindow", "Clear selection list"))
        self.bNext.setToolTip(_translate("Q7VTKWindow", "Highlight next selected item"))
from CGNS.NAV.Q7VTKRenderWindowInteractor import Q7VTKRenderWindowInteractor
from CGNS.NAV.wvtkutils import Q7ComboBox
from . import Res_rc
