/* ======================================================================
 * CHLone - CGNS HDF5 LIBRARY only node edition
 * See license.txt in the root directory of this source release
 * ====================================================================== */

{3000,1,"File '%s' not found (read only mode)"},/*@<filename>@*/
{3001,1,"File '%s' not found (modify mode)"},/*@<filename>@*/
{3002,1,"Create file '%s' fails"},/*@<filename>@*/
{3003,1,"Update file '%s' fails"},/*@<filename>@*/
{3004,1,"Open file '%s' as read only fails"},/* @<filename>@*/
{3010,1,"Unknown file mode (integer=%d)"},/*@<filename>@*/
{3011,1,"Property list fails for 'file'"},/*@@*/
{3012,1,"Property list fails for 'link'"},/*@@*/
{3013,1,"Property list fails for 'group'"},/*@@*/
{3017,1,"L3 HDF_Add_DataArray: DataType not found in this node"},/*@@*/
{3018,1,"L3 HDF_Set_DataArray: DataType not found in [%s]"},/*@<nodename>@*/
{3019,1,"L3 HDF_Get_DataArray: DataType not found in this node"},/*@@*/
{3020,1,"No data to get in this node"},/*@@*/
{3021,1,"No data to set in this node"},/*@@*/
{3022,1,"Create root fails while trying H5Gopen2"},/*@@*/
{3023,1,"Create root fails while trying to add HDF5 MotherNode"},/*@@*/
{3024,1,"Create root fails while trying to add Root Node"},/*@@*/
{3025,1,"Create root fails while trying to set MT"},/*@@*/
{3026,1,"Create root fails while trying to set format"},/*@@*/
{3027,1,"Create root fails while trying to set version"},/*@@*/
{3028,1,"L3 HDF_Get_DataArrayPartial bad hyperslab parameters"},/*@@*/
{3030,1,"Bad nodeCreate: cannot create node [%s]"},/*@<nodename>@*/
{3031,1,"Bad nodeCreate: cannot add name attribute [%s]"},/*@<attributename>@*/  
{3032,1,"Bad nodeCreate: cannot add 'label' attribute"},/*@@*/  
{3033,1,"Bad nodeCreate: cannot add 'datatype' attribute"},/*@@*/  
{3034,1,"Bad nodeCreate: cannot add data"},/*@@*/  
{3035,1,"Bad nodeCreate: empty data in non-MT node"},/*@@*/  
{3036,1,"Bad nodeCreate: cannot add flags"},/*@@*/  
{3037,1,"Bad nodeCreate: bode name rejected [%s]"},/*@<nodename>@*/  
{3040,1,"Bad nodeMove: source/destination is a link"},/*@@*/
{3041,1,"Bad nodeMove: cannot change name attribute"},/*@@*/
{3050,1,"Bad nodeUpdate: cannot update a link"},/*@@*/
{3051,1,"Bad nodeUpdate: bad node id"},/*@@*/
{3052,1,"Bad nodeUpdate: cannot change name on [%s]"},/*@<nodename>@*/
{3053,1,"Bad nodeUpdate: cannot update label on [%s]"},/*@<nodename>@*/
{3054,1,"Bad nodeUpdate: cannot update dtype on [%s]"},/*@<nodename>@*/
{3055,1,"L3 nodeUpdate: cannot update data on [%s]"},/*@<nodename>@*/
{3056,1,"Bad nodeUpdate: cannot update flags on [%s]"},/*@<nodename>@*/
{3060,1,"Bad nodeLink: parent already is a link"},/*@@*/ 
{3061,1,"Bad nodeLink: cannot create node [%s]"},/*@<nodename>@*/
{3062,1,"Bad nodeLink: cannot add name attribute [%s]"},/*@<nodename>@*/
{3063,1,"Bad nodeLink: cannot set LK type"},/*@@*/
{3064,1,"Bad nodeLink: cannot set empty label"},/*@@*/
{3070,1,"Bad nodeDelete: bad parent node id"},/*@@*/
{3080,1,"Bad nodeFind: path too long (%d chars)"},/*@<pathsize>@*/
{3081,1,"Bad nodeFind: bad parent node id"},/*@@*/
{3090,1,"Bad nodeRetrieve: bad node id"},/*@@*/
{3091,1,"Bad nodeRetrieve: link not found"},/*@@*/
{3092,1,"Bad nodeRetrieve: node to return not allocated"},/*@@*/
{3093,1,"Bad node2Path: invalid node id [%d]"},/*@<id>@*/
{3100,1,"L3 context is NULL"},/*@@*/

/* --- last line ----------------------------------------------------------- */
